@@ -1,8 +1,4 @@
-from rlbot.messages.flat import MatchSettings
 from rlbot.parsing.custom_config import ConfigObject
-from rlbot.utils.game_state_util import GameState
-from rlbot.utils.structures.ball_prediction_struct import BallPrediction
-from rlbot.utils.structures.rigid_body_struct import RigidBodyTick
 
 LOCATIONS_HEADER = 'Locations'
 DETAILS_HEADER = 'Details'
@@ -12,6 +8,7 @@ LOGO_FILE_KEY = 'logo_file'
 NAME_KEY = "name"
 SUPPORTS_EARLY_START_KEY = "supports_early_start"
 REQUIRES_TKINTER = "requires_tkinter"
+USE_VIRTUAL_ENVIRONMENT_KEY = "use_virtual_environment"
 
 
 class RLBotRunnable:
@@ -27,24 +24,6 @@ class RLBotRunnable:
         """
         pass
 
-    def get_field_info(self):
-        raise NotImplementedError
-
-    def get_rigid_body_tick(self) -> RigidBodyTick:
-        """Get the most recent state of the physics engine."""
-        return self.__get_rigid_body_tick_func()
-
-    def set_game_state(self, game_state: GameState):
-        raise NotImplementedError
-
-    def get_ball_prediction_struct(self) -> BallPrediction:
-        raise NotImplementedError
-
-    def get_match_settings(self) -> MatchSettings:
-        """Gets the current match settings in flatbuffer format. Useful for determining map, game mode,
-        mutator settings, etc."""
-        raise NotImplementedError
-
     def initialize_agent(self):
         """
         Called for all heaver initialization that needs to happen.
@@ -93,6 +72,8 @@ class RLBotRunnable:
                                   description="True if this bot can be started before the Rocket League match begins.")
         location_config.add_value(REQUIRES_TKINTER, bool,
                                   description="True if the tkinter library is needed.")
+        location_config.add_value(USE_VIRTUAL_ENVIRONMENT_KEY, bool,
+                                  description="True if the runnable wants to run in a virtual environment.")
 
         details_config = config.add_header_name(DETAILS_HEADER)
         details_config.add_value('developer', str, description="Name of the bot's creator/developer")
