@@ -4,10 +4,16 @@
 # 3) we can import it into your module module
 # https://stackoverflow.com/questions/458550/standard-way-to-embed-version-into-python-package
 
-__version__ = '1.55.2'
+__version__ = '1.56.2'
 
 release_notes = {
-    '1.55.2': """
+    '1.56.2': """
+    Support for Gridiron mode!
+    
+    Passing matchcomms-url to Java and C# bots as a command line argument.
+    See https://github.com/RLBot/RLBot/wiki/Matchcomms for more information.
+    """,
+    '1.55.7': """
     Using sockets for match start, lifting the restrictions on max players when using flatbuffers,
     and sending a game tick packet immediately upon socket connection to fix some bugs.
     """,
